#
# spec file for package python-django-invitations
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-django-invitations
Version:        2.1.0
Release:        1.6
Summary:        Generic invitations app with support for Django-allauth
License:        GPL-3.0-only
URL:            https://github.com/bee-keeper/django-invitations
Source:         https://github.com/bee-keeper/django-invitations/archive/%{version}.tar.gz
BuildRequires:  %{python_module Django >= 1.11}
BuildRequires:  %{python_module django-allauth}
BuildRequires:  %{python_module freezegun >= 0.3.5}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module poetry-core}
BuildRequires:  %{python_module pytest >= 3.0.7}
BuildRequires:  %{python_module pytest-django >= 3.1.2}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Django >= 1.11
Recommends:     python-django-allauth
BuildArch:      noarch
%python_subpackages

%description
Generic invitations app with support for Django-allauth.

%prep
%autosetup -p1 -n django-invitations-%{version}
rm tox.ini

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest tests/basic/tests.py --ds=test_settings
%pytest tests/allauth/test_allauth.py --ds=test_allauth_settings

%files %{python_files}
%license LICENSE
%doc CHANGELOG.md README.md
%{python_sitelib}/invitations
%{python_sitelib}/django_invitations-%{version}*-info

%changelog
* Tue Dec  5 2023 Dirk Müller <dmueller@suse.com>
- update to 2.1.0:
  * French translation
  * Translation Portuguese (BR)
  * Add default_auto_field and migration.
  * Add missing configuration values for test_settings.
  * Remove mention of sites framework from docs
- drop configure-django.patch (upstream)
* Fri Nov 17 2023 Matej Cepl <mcepl@cepl.eu>
- Update to 2.0.0:
  - Added Ukrainian language
  - MANIFEST.in: Include usual targets
  - JazzBand project guidelines
  - Update import for django 4.0
  - Update README.md
  - Add django 4.0 and python 3.9/3.10 to test matrix.
  - Fix docstring for accepted invite signal
  - Passed request as an argument into invite_accepted signal
  - refactor(models): use get_current_site from django shortcuts
  - Make "inviter" be an raw_id_field in admin
  - Add i18n tags
  - Add invitation object as an argument to the invite accepted signal
  - Set inviter in SendJSONInvite
  - Make accept-invite viewname configurable in django settings
  - Use poetry for package management.
  - Sphinx based documentation
  - Add documentation for swappable forms.
  - Correct spelling mistakes
  - Fix release workflow to actually publish
  - Fix flake8 and tox dependencies
- Remove upstreamed patches:
  - django-4.0.patch
  - python-django-invitations-no-mock.patch
- Add configure-django.patch to add missing configuration values
  for Django.
* Mon May  9 2022 pgajdos@suse.com
- do not require python-mock for build
- added patches
  https://github.com/jazzband/django-invitations/blob/master/tests/basic/tests.py#L4
  + python-django-invitations-no-mock.patch
* Tue Mar  1 2022 Steve Kowalik <steven.kowalik@suse.com>
- Add patch django-4.0.patch:
  * Support Django 4.0
* Thu Feb 20 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.9.3:
  * support new django
- Remove patch django20.patch
* Wed Feb  5 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable py2 build as deps are only for python 3
* Mon Sep 16 2019 Tomáš Chvátal <tchvatal@suse.com>
- Skip one failing test which is caused by django-pytest
* Tue Mar  5 2019 Tomáš Chvátal <tchvatal@suse.com>
- Switch to github archive to not differ from the fetched files
- Add patch to work with django2.0+:
  * django20.patch
* Sat Feb 16 2019 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v1.9.2
